@@ -5,29 +5,27 @@
 */
 
 #include "mergedialog.h"
-#include "hgwrapper.h"
-#include "commititemdelegate.h"
 #include "commitinfowidget.h"
+#include "commititemdelegate.h"
 #include "fileviewhgpluginsettings.h"
+#include "hgwrapper.h"
 
-#include <QLabel>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QTextEdit>
-#include <QListWidgetItem>
-#include <QTextCodec>
 #include <KLocalizedString>
 #include <KMessageBox>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QListWidgetItem>
+#include <QTextEdit>
+#include <QVBoxLayout>
 
-HgMergeDialog::HgMergeDialog(QWidget *parent):
-    DialogBase(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, parent)
+HgMergeDialog::HgMergeDialog(QWidget *parent)
+    : DialogBase(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, parent)
 {
     // dialog properties
-    this->setWindowTitle(xi18nc("@title:window",
-                "<application>Hg</application> Merge"));
+    this->setWindowTitle(xi18nc("@title:window", "<application>Hg</application> Merge"));
     okButton()->setText(xi18nc("@label:button", "Merge"));
 
-    // UI 
+    // UI
 
     m_currentChangeset = new QLabel;
     m_commitInfoWidget = new HgCommitInfoWidget;
@@ -42,8 +40,7 @@ HgMergeDialog::HgMergeDialog(QWidget *parent):
 
     // load saved geometry
     FileViewHgPluginSettings *settings = FileViewHgPluginSettings::self();
-    this->resize(QSize(settings->mergeDialogWidth(),
-                               settings->mergeDialogHeight()));
+    this->resize(QSize(settings->mergeDialogWidth(), settings->mergeDialogHeight()));
 
     // connections
     connect(this, SIGNAL(finished(int)), this, SLOT(saveGeometry()));
@@ -77,11 +74,11 @@ void HgMergeDialog::updateInitialDialog()
     while (process.waitForReadyRead()) {
         while (process.readLine(buffer[count], sizeof(buffer[count])) > 0) {
             if (count == FINAL - 1) {
-                QString rev = QTextCodec::codecForLocale()->toUnicode(buffer[0]).trimmed();
-                QString changeset = QTextCodec::codecForLocale()->toUnicode(buffer[1]).trimmed();
-                QString branch = QTextCodec::codecForLocale()->toUnicode(buffer[2]).trimmed();
-                QString author = QTextCodec::codecForLocale()->toUnicode(buffer[3]).trimmed();
-                QString log = QTextCodec::codecForLocale()->toUnicode(buffer[4]).trimmed();
+                QString rev = QString::fromLocal8Bit(buffer[0]).trimmed();
+                QString changeset = QString::fromLocal8Bit(buffer[1]).trimmed();
+                QString branch = QString::fromLocal8Bit(buffer[2]).trimmed();
+                QString author = QString::fromLocal8Bit(buffer[3]).trimmed();
+                QString log = QString::fromLocal8Bit(buffer[4]).trimmed();
 
                 QListWidgetItem *item = new QListWidgetItem;
                 item->setData(Qt::DisplayRole, changeset);
@@ -90,9 +87,8 @@ void HgMergeDialog::updateInitialDialog()
                 item->setData(Qt::UserRole + 3, author);
                 item->setData(Qt::UserRole + 4, log);
                 m_commitInfoWidget->addItem(item);
-
             }
-            count = (count + 1)%FINAL;
+            count = (count + 1) % FINAL;
         }
     }
 }
@@ -104,8 +100,7 @@ void HgMergeDialog::done(int r)
 
         QListWidgetItem *currentItem = m_commitInfoWidget->currentItem();
         if (currentItem == nullptr) {
-            KMessageBox::error(this,
-                    xi18nc("@message", "No head selected for merge!"));
+            KMessageBox::error(this, xi18nc("@message", "No head selected for merge!"));
             return;
         }
 
@@ -118,13 +113,11 @@ void HgMergeDialog::done(int r)
         if (hgw->executeCommandTillFinished(QStringLiteral("merge"), args)) {
             KMessageBox::information(this, hgw->readAllStandardOutput());
             QDialog::done(r);
-        }
-        else {
+        } else {
             KMessageBox::error(this, hgw->readAllStandardError());
             return;
         }
-    }
-    else {
+    } else {
         QDialog::done(r);
     }
 }
@@ -137,6 +130,4 @@ void HgMergeDialog::saveGeometry()
     settings->save();
 }
 
-
-
 #include "moc_mergedialog.cpp"
